Data Base Classes
==================

This module provides base classes for data handling in concept-based models.

Summary
-------

**Dataset Base Classes**

.. currentmodule:: torch_concepts.data.base.dataset
.. autosummary::
   :toctree: generated
   :nosignatures:

   ConceptDataset

**DataModule Base Classes**

.. currentmodule:: torch_concepts.data.base.datamodule
.. autosummary::
   :toctree: generated
   :nosignatures:

   ConceptDataModule

**Scaler Base Classes**

.. currentmodule:: torch_concepts.data.base.scaler
.. autosummary::
   :toctree: generated
   :nosignatures:

   Scaler

**Splitter Base Classes**

.. currentmodule:: torch_concepts.data.base.splitter
.. autosummary::
   :toctree: generated
   :nosignatures:

   Splitter


Class Documentation
-------------------

Dataset Classes
~~~~~~~~~~~~~~~

.. autoclass:: torch_concepts.data.base.dataset.ConceptDataset
   :members:
   :undoc-members:
   :show-inheritance:

DataModule Classes
~~~~~~~~~~~~~~~~~~

.. autoclass:: torch_concepts.data.base.datamodule.ConceptDataModule
   :members:
   :undoc-members:
   :show-inheritance:

Scaler Classes
~~~~~~~~~~~~~~

.. autoclass:: torch_concepts.data.base.scaler.Scaler
   :members:
   :undoc-members:
   :show-inheritance:

Splitter Classes
~~~~~~~~~~~~~~~~

.. autoclass:: torch_concepts.data.base.splitter.Splitter
   :members:
   :undoc-members:
   :show-inheritance:
